@@ -21,6 +21,13 @@ from Mailman.Mailbox import ArchiverMailbox
 from Mailman.Logging.Syslog import syslog
 from Mailman.i18n import _
 
+# True/False
+try:
+    True, False
+except NameError:
+    True = 1
+    False = 0
+
 SPACE = ' '
 
 
@@ -217,7 +224,7 @@ class Article:
                 self.headers[i] = message[i]
 
         # Read the message body
-        s = StringIO(message.get_payload(decode=1)\
+        s = StringIO(message.get_payload(decode=True)\
                      or message.as_string().split('\n\n',1)[1])
         self.body = s.readlines()
 
