@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2005 Python Software Foundation
+# Copyright (C) 2001-2006 Python Software Foundation
 # Author: barry@python.org (Barry Warsaw)
 
 """Basic message object for the email package object model."""
@@ -23,6 +23,12 @@ except NameError:
     True = 1
     False = 0
 
+try:
+    from email._compat22 import quiet_uu_decode
+except SyntaxError:
+    from email._compat21 import quiet_uu_decode
+
+
 # Regular expression used to split header parameters.  BAW: this may be too
 # simple.  It isn't strictly RFC 2045 (section 5.1) compliant, but it catches
 # most headers found in the wild.  We may eventually need a full fledged
@@ -220,7 +226,7 @@ class Message:
             elif cte in ('x-uuencode', 'uuencode', 'uue', 'x-uue'):
                 sfp = StringIO()
                 try:
-                    uu.decode(StringIO(payload+'\n'), sfp)
+                    quiet_uu_decode(StringIO(payload+'\n'), sfp, quiet=True)
                     payload = sfp.getvalue()
                 except uu.Error:
                     # Some decoding problem
@@ -272,11 +278,14 @@ class Message:
                             charset=charset.get_output_charset())
         else:
             self.set_param('charset', charset.get_output_charset())
+        if str(charset) <> charset.get_output_charset():
+            self._payload = charset.body_encode(self._payload)
         if not self.has_key('Content-Transfer-Encoding'):
             cte = charset.get_body_encoding()
             if callable(cte):
                 cte(self)
             else:
+                self._payload = charset.body_encode(self._payload)
                 self.add_header('Content-Transfer-Encoding', cte)
 
     def get_charset(self):
@@ -718,10 +727,15 @@ class Message:
         """Return the filename associated with the payload if present.
 
         The filename is extracted from the Content-Disposition header's
-        `filename' parameter, and it is unquoted.
+        `filename' parameter, and it is unquoted.  If that header is missing
+        the `filename' parameter, this method falls back to looking for the
+        `name' parameter.
         """
         missing = []
         filename = self.get_param('filename', missing, 'content-disposition')
+        if filename is missing:
+            # Some MUAs use a different parameter name
+            filename = self.get_param('name', missing, 'content-disposition')
         if filename is missing:
             return failobj
         if isinstance(filename, TupleType):
